@@ -189,7 +189,7 @@ class QueryBuffer:
                 del _filters[item]
         return query, _filters
 
-    def all(self, counts=True):
+    def all(self, counts=False):
         if self.paginated:
             self.data = self.pagedquery.items
             self.count = getattr(self.basequery, 'count')()
